@@ -1,4 +1,4 @@
 from .vec2 import Vec2
 from .vec3 import Vec3
 from .vec4 import Vec4
-import locals
+from .locals import *
